@@ -1,15 +1,18 @@
 /*----------------------------------------------------------------------
-    Character segmentation function    segchar.cpp
+    Character segmentation function    segchar_adhoc.cpp
       (Ad-hoc version)
         Written by H.Goto, Jan. 2008
         Revised by H.Goto, Feb. 2008
         Revised by H.Goto, Sep. 2008
         Revised by H.Goto, Jan. 2009
         Revised by H.Goto, May  2009
+        Revised by H.Goto, July 2009
+        Revised by H.Goto, Oct. 2009
+        Revised by H.Goto, Aug. 2014
 ----------------------------------------------------------------------*/
 
 /*--------------
-  Copyright 2008,2009  Hideaki Goto
+  Copyright 2008-2014  Hideaki Goto
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -712,7 +715,7 @@ static int refine_charbox_2(SIPImage *lineimage, \
 int segmentchars(SIPImage *lineimage, \
 	CharBox *cba, CharBox *cba_raw, \
 	double *avrcwidth, double *lineheight, double *charpitch, \
-	int debug){
+	int force_alpha, int wdir, int debug){
 	int	x,y;
 	int	width,height,charsize;
 	uchar	**p;
@@ -775,7 +778,7 @@ int segmentchars(SIPImage *lineimage, \
 				cb->nbox = 1;
 				cb->xs = lc;	cb->xe = x;
 				cb->ys = ys;	cb->ye = ye;
-				cb->ascii = 0;
+				cb->alphamode = 0;
 //	p[0][lc] = p[0][x] = 127;
 				break;
 			}
@@ -785,7 +788,7 @@ int segmentchars(SIPImage *lineimage, \
 			cb->nbox = 1;
 			cb->xs = lc;	cb->xe = x;
 			cb->ys = ys;	cb->ye = ye;
-			cb->ascii = 0;
+			cb->alphamode = 0;
 //	p[0][lc] = p[0][x] = 127;
 		}
 	}
@@ -815,6 +818,8 @@ int segmentchars(SIPImage *lineimage, \
 	if ( avr_pitch/lheight > .9 ){
 		amode = 0;
 	}
+	if ( force_alpha )  amode = 1;
+
 	if ( ! amode ){
 		// 1st refinement
 		refine_charbox_1(lineimage, cba, \
@@ -835,7 +840,7 @@ int segmentchars(SIPImage *lineimage, \
 			charsize = cb->height();
 		}
 		if ( amode ){
-			cb->ascii = 1;
+			cb->alphamode = 1;
 		}
 
 		// character size estimation
@@ -859,13 +864,25 @@ int segmentchars(SIPImage *lineimage, \
 		h = bottom[x] - top[x] +1;
 		yb = yt + h /5;
 		yt -= h /3;
-		if ( y < yt ){
-			cb->poshint |= PosHint_Top;
+		if ( wdir & WrtDir_H ){	// horizontal mode
+			if ( y < yt ){
+				cb->poshint |= PosHint_Top;
+			}
+			else if ( y > yb ){
+				cb->poshint |= PosHint_Bottom;
+			}
+			else{	cb->poshint |= PosHint_Middle;
+			}
 		}
-		else if ( y > yb ){
-			cb->poshint |= PosHint_Bottom;
-		}
-		else{	cb->poshint |= PosHint_Middle;
+		else{	// vertical mode
+			if ( y < yt ){
+				cb->poshint |= PosHint_Right;
+			}
+			else if ( y > yb ){
+				cb->poshint |= PosHint_Left;
+			}
+			else{	cb->poshint |= PosHint_Center;
+			}
 		}
 	}
 
