@@ -1,5 +1,5 @@
 /*----------------------------------------------------------------------
-    Character segmentation function    segchar.h
+    Character segmentation function    segchar_adhoc.h
       (an Ad-hoc version)
         Written by H.Goto, Jan. 2008
         Revised by H.Goto, Feb. 2008
@@ -7,10 +7,14 @@
         Revised by H.Goto, Sep. 2008
         Revised by H.Goto, Jan. 2009
         Revised by H.Goto, May  2009
+        Revised by H.Goto, July 2009
+        Revised by H.Goto, Oct. 2009
+        Revised by H.Goto, Jan. 2013
+        Revised by H.Goto, Aug. 2014
 ----------------------------------------------------------------------*/
 
 /*--------------
-  Copyright 2008,2009  Hideaki Goto
+  Copyright 2008-2014 Hideaki Goto
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -38,8 +42,8 @@ extern "C" {
 int	segmentchars(SIPImage *lineimage, \
 		CharBox *cba, CharBox *cba_raw, \
 		double *avrcwidth, double *lineheight, double *charpitch, \
-		int debug);
-void	delete_cblist(CharBox *cblist);
+		int force_alpha, int wdir, int debug);
+//void	delete_cblist(CharBox *cblist);
 
 }
 
